#!/usr/local/bin/wish8.0
# A Notebook widget for Tcl/Tk
# $Revision: 1.2 $
#
# Copyright (C) 1996,1997,1998 D. Richard Hipp
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Library General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Library General Public License for more details.
# 
# You should have received a copy of the GNU Library General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA  02111-1307, USA.
#
# Author contact information:
#   drh@acm.org
#   http://www.hwaci.com/drh/
#
#
global assesment; set assesment " "
global objective; set objective " "
global plan; set plan " "
global subjective; set subjective " "
#
#
# Create a new notebook widget
#
proc Notebook:create {w args} {
  global Notebook
  set Notebook($w,width) 800
  set Notebook($w,height) 600
  set Notebook($w,pages) {}
  set Notebook($w,top) 0
  set Notebook($w,pad) 5
  set Notebook($w,fg,on) red
  set Notebook($w,fg,off) grey50
  canvas $w -bd 0 -highlightthickness 0 -takefocus 0
  set Notebook($w,bg) [$w cget -bg]
  bind $w <1> "Notebook:click $w %x %y"
  eval Notebook:config $w $args
}

#
# Change configuration options for the notebook widget
#
proc Notebook:config {w args} {
  global Notebook
  foreach {tag value} $args {
    switch -- $tag {
      -width {
        set Notebook($w,width) $value
      }
      -height {
        set Notebook($w,height) $value
      }
      -pages {
        set Notebook($w,pages) $value
      }
      -pad {
        set Notebook($w,pad) $value
      }
      -bg {
        set Notebook($w,bg) $value
      }
      -fg {
        set Notebook($w,fg,on) $value
      }
      -disabledforeground {
        set Notebook($w,fg,off) $value
      }
    }
  }

  #
  # After getting new configuration values, reconstruct the widget
  #
  $w delete all
  set Notebook($w,x1) $Notebook($w,pad)
  set Notebook($w,x2) [expr $Notebook($w,x1)+2]
  set Notebook($w,x3) [expr $Notebook($w,x2)+$Notebook($w,width)]
  set Notebook($w,x4) [expr $Notebook($w,x3)+2]
  set Notebook($w,y1) [expr $Notebook($w,pad)+2]
  set Notebook($w,y2) [expr $Notebook($w,y1)+2]
  set Notebook($w,y5) [expr $Notebook($w,y1)+30]
  set Notebook($w,y6) [expr $Notebook($w,y5)+2]
  set Notebook($w,y3) [expr $Notebook($w,y6)+$Notebook($w,height)]
  set Notebook($w,y4) [expr $Notebook($w,y3)+2]
  set x $Notebook($w,x1)
  set cnt 0
  set y7 [expr $Notebook($w,y1)+10]
  foreach p $Notebook($w,pages) {
    set Notebook($w,p$cnt,x5) $x
    set id [$w create text 0 0 -text $p -anchor nw -tags "p$cnt t$cnt"]
    set bbox [$w bbox $id]
    set width [lindex $bbox 2]
    $w move $id [expr $x+10] $y7
    $w create line \
       $x $Notebook($w,y5)\
       $x $Notebook($w,y2) \
       [expr $x+2] $Notebook($w,y1) \
       [expr $x+$width+16] $Notebook($w,y1) \
       -width 2 -fill white -tags p$cnt
    $w create line \
       [expr $x+$width+16] $Notebook($w,y1) \
       [expr $x+$width+18] $Notebook($w,y2) \
       [expr $x+$width+18] $Notebook($w,y5) \
       -width 2 -fill black -tags p$cnt
    set x [expr $x+$width+20]
    set Notebook($w,p$cnt,x6) [expr $x-2]
    if {![winfo exists $w.f$cnt]} {
      frame $w.f$cnt -bd 0
    }
    $w.f$cnt config -bg $Notebook($w,bg)
    place $w.f$cnt -x $Notebook($w,x2) -y $Notebook($w,y6) \
      -width $Notebook($w,width) -height $Notebook($w,height)
    incr cnt
  }
  $w create line \
     $Notebook($w,x1) [expr $Notebook($w,y5)-2] \
     $Notebook($w,x1) $Notebook($w,y3) \
     -width 2 -fill white
  $w create line \
     $Notebook($w,x1) $Notebook($w,y3) \
     $Notebook($w,x2) $Notebook($w,y4) \
     $Notebook($w,x3) $Notebook($w,y4) \
     $Notebook($w,x4) $Notebook($w,y3) \
     $Notebook($w,x4) $Notebook($w,y6) \
     $Notebook($w,x3) $Notebook($w,y5) \
     -width 2 -fill black
  $w config -width [expr $Notebook($w,x4)+$Notebook($w,pad)] \
            -height [expr $Notebook($w,y4)+$Notebook($w,pad)] \
            -bg $Notebook($w,bg)
  set top $Notebook($w,top)
  set Notebook($w,top) -1
  Notebook:raise.page $w $top
}

#
# This routine is called whenever the mouse-button is pressed over
# the notebook.  It determines if any page should be raised and raises
# that page.
#
proc Notebook:click {w x y} {
  global Notebook
  if {$y<$Notebook($w,y1) || $y>$Notebook($w,y6)} return
  set N [llength $Notebook($w,pages)]
  for {set i 0} {$i<$N} {incr i} {
    if {$x>=$Notebook($w,p$i,x5) && $x<=$Notebook($w,p$i,x6)} {
      Notebook:raise.page $w $i
      break
    }
  }
}

#
# For internal use only.  This procedure raised the n-th page of
# the notebook
#
proc Notebook:raise.page {w n} {
  global Notebook
  if {$n<0 || $n>=[llength $Notebook($w,pages)]} return
  set top $Notebook($w,top)
  if {$top>=0 && $top<[llength $Notebook($w,pages)]} {
    $w move p$top 0 6
  }
  $w move p$n 0 -6
  $w delete topline
  if {$n>0} {
    $w create line \
       $Notebook($w,x1) $Notebook($w,y6) \
       $Notebook($w,x2) $Notebook($w,y5) \
       $Notebook($w,p$n,x5) $Notebook($w,y5) \
       $Notebook($w,p$n,x5) [expr $Notebook($w,y5)-6] \
       -width 6 -fill white -tags topline
  }
  $w create line \
    $Notebook($w,p$n,x6) [expr $Notebook($w,y5)-6] \
    $Notebook($w,p$n,x6) $Notebook($w,y5) \
    -width 6 -fill white -tags topline
  $w create line \
    $Notebook($w,p$n,x6) $Notebook($w,y5) \
    $Notebook($w,x3) $Notebook($w,y5) \
    -width 6 -fill white -tags topline
  set Notebook($w,top) $n
  raise $w.f$n
}

#
# Change the page-specific configuration options for the notebook
#
proc Notebook:pageconfig {w name args} {
  global Notebook
  set i [lsearch $Notebook($w,pages) $name]
  if {$i<0} return
  foreach {tag value} $args {
    switch -- $tag {
      -state {
        if {"$value"=="disabled"} {
          $w itemconfig t$i -fg $Notebook($w,fg,off)
        } else {
          $w itemconfig t$i -fg $Notebook($w,fg,on)
        }
      }
      -onexit {
        set Notebook($w,p$i,onexit) $value
      }
    }
  }
}

#
# This procedure raises a notebook page given its name.  But first
# we check the "onexit" procedure for the current page (if any) and
# if it returns false, we don't allow the raise to proceed.
#
proc Notebook:raise {w name} {
  global Notebook
  set i [lsearch $Notebook($w,pages) $name]
  if {$i<0} return
  if {[info exists Notebook($w,p$i,onexit)]} {
    set onexit $Notebook($w,p$i,onexit)
    if {"$onexit"!="" && [eval uplevel #0 $onexit]!=0} {
      Notebook:raise.page $w $i
    }
  } else {
    Notebook:raise.page $w $i
  }
}

#
# Return the frame associated with a given page of the notebook.
#
proc Notebook:frame {w name} {
  global Notebook
  set i [lsearch $Notebook($w,pages) $name]
  if {$i>=0} {
    return $w.f$i
  } else {
    return {}
  }
}

proc CanvasMark { x y w } {
     global canvas
     # Remember the object and its location
     set canvas($w,obj) [$w find closest $x $y]
     set canvas($w,x) $x
     set canvas($w,y) $y
}

proc CanvasDrag { x y w } {
     # Move the current object
     global canvas
     set dx [expr $x - $canvas($w,x)]
     set dy [expr $y - $canvas($w,y)]
     $w move $canvas($w,obj) $dx $dy
     set canvas($w,x) $x
     set canvas($w,y) $y
}


############################################################################################
#proc {generate} {temperature} {
#global subjective objective assesment plan

#set name "Doe, John M."   
#.top.n.f8.1.frame.text delete 1.0 end
#.top.n.f8.1.frame.text configure -state normal




#.top.n.f8.1.frame.text insert end "[clock format [clock seconds] -format "%x %R"] \n"
#.top.n.f8.1.frame.text insert end "$name\n"
#.top.n.f8.1.frame.text insert end "Problem: Asthma \n"

#.top.n.f8.1.frame.text insert end "Subjective: "

#for { set x 0 } {$x < [llength $subjective]} {incr x} { .top.n.f8.1.frame.text insert end [lindex $subjective $x];.top.n.f8.1.frame.text insert end " " }

#.top.n.f8.1.frame.text insert end "\n"
#.top.n.f8.1.frame.text insert end "Objective: Weight: 150 Height: 65 BP 120/80 Temp: $temperature Resp: 20\n"

#for { set x 0 } {$x < [llength $objective]}  {incr x} { .top.n.f8.1.frame.text insert end [lindex $objective $x];.top.n.f8.1.frame.text insert end " " }

#.top.n.f8.1.frame.text insert end "\n"
#.top.n.f8.1.frame.text insert end "Assesment: "

#for {set x 0 } {$x < [llength $assesment]} {incr x} { .top.n.f8.1.frame.text insert end [lindex $assesment $x];.top.n.f8.1.frame.text insert end " "}

#.top.n.f8.1.frame.text insert end "\n"
#.top.n.f8.1.frame.text insert end "Plan: "

#for {set x 0 } {$x < [llength $plan]} {incr x} {.top.n.f8.1.frame.text insert end [lindex $plan $x];.top.n.f8.1.frame.text insert end " "}


#.top.n.f8.1.frame.text insert end "\n"
;#.top.n.f8.1.frame.text insert end "<IMG SRC=signature.gif width=250 height=30>\n<BR>"
#.top.n.f8.1.frame.text insert end "Alexander Caldwell M.D.\n"
;#.top.n.f8.1.frame.text insert end "<HR>\n"
;#.top.n.f8.1.frame.text insert end "</HTML>\n"

#}

proc drawline {c a b} {

set xdif [expr [lindex [$c bbox $b] 2] - [lindex [$c coords $b] 0]]


set ydif [expr [lindex [$c bbox $b] 3] - [lindex [$c coords $b] 1]]


$c  create line [lindex [$c coords $a] 0] [lindex [$c coords $a] 1]\
 [expr [lindex [$c coords $b] 0] - $xdif] [expr [lindex [$c coords $b] 1] - $ydif] \
 -fill yellow -width 3 -arrow last -arrowshape {6 10 4} -splinesteps 20 -smooth 1 -tag movable

}

proc drawloop {c a} {

$c create line [lindex [$c coords $a] 0] [lindex [$c coords $a] 1] \
[expr [lindex [$c coords $a] 0] + 200] [expr [lindex [$c coords $a] 1] - 50] \
[expr [lindex [$c coords $a] 0] + 200] [expr [lindex [$c coords $a] 1] + 50] \
[lindex [$c bbox $a] 2] [lindex [$c bbox $a] 3] \
-fill yellow -width 3 -arrow last -arrowshape {6 10 4} -splinesteps 5 -smooth 1 -tag movable
}
############################################################################################
# The following code implements an example of using the
# notebook widget.
#
toplevel .top
Notebook:create .top.n -pages {Intro Worse Symptoms Diagnosis Classification  Staging  Treatment Education Prog.Note} -pad 20 
pack .top.n
wm title .top "Ashtma Algorithm"
#############################################################################################
#############################################################################################
# Asthma Intro Notebook Page
set w [Notebook:frame .top.n Intro]

canvas $w.1 -relief groove -bg black -yscrollcommand "$w.sb1 set" -xscrollcommand "$w.sb2 set" -scrollregion {0 0 1200 1200}
scrollbar $w.sb2 -orient horizontal -command "$w.1 xview"
;#pack $w.sb2 -side bottom -fill x
scrollbar $w.sb1 -orient vertical -command "$w.1 yview"
pack $w.sb1 -side right -fill y
pack $w.sb2 -side bottom -fill x
pack $w.1 -side left  -fill both -expand 1

message $w.1.mes1  -text "Patient with Sx...  Wheeze, Cough, Shortness of Breath..."  -fg black -bg goldenrod \
-aspect 150 
$w.1 create window 58 50  -window $w.1.mes1 -tag $w.1.mes1

bind $w.1.mes1 <Button-1> {frame .frame04 -bg red;place .frame04 -x 58 -y 50 -height 208 -width 308
message .frame04.box04message -aspect 150 -bg ivory -text "These symptoms suggest the possibility
of asthma but need to be considered in relation to the various other possible diagnoses that could
be confused with asthma in the different age groups."
place .frame04.box04message -x 4 -y 4 -height 200 -width 300 -anchor nw -bordermode ignore
bind .frame04.box04message <Button-1> {destroy .frame04}}

message $w.1.mes2 -text "Is Patient worse than usual?" -bg red -fg yellow -aspect 150 
$w.1 create window 53 145  -window $w.1.mes2 -tag $w.1.mes2 -tag $w.1.mes2

bind $w.1.mes2 <Button-1> {frame .frame05 -bg red;place .frame05 -x 53 -y 145 -height 208 -width 308
message .frame05.box05message -aspect 150 -bg ivory -text "If the patient is not at his or her baseline
then there is another MAP under the tab \"Worse\" that needs to be followed."
place .frame05.box05message -x 4 -y 4 -height 200 -width 300 -anchor nw -bordermode ignore
bind .frame05.box05message <Button-1> {destroy .frame05}}


button $w.1.reset -text "RESET" -command "$w.1.mes2 config -fg yellow -bg red  
;#$w.1.mes3 config -bg gray -fg gray50
$w.1.mes4 config -bg gray -fg gray50
$w.1.mes5 config -bg gray -fg gray50
$w.1.mes6 config -bg gray -fg gray50
$w.1.mes7 config -bg gray -fg gray50
$w.1.mes8 config -bg gray -fg gray50
$w.1.mes9 config -bg gray -fg gray50
$w.1.mes10 config -bg gray -fg gray50
$w.1.mes11 config -bg gray -fg gray50
$w.1.mes12 config -bg gray -fg gray50
$w.1.mes13 config -bg gray -fg gray50
$w.1.mes14 config -bg gray -fg gray50
$w.1.mes15 config -bg gray -fg gray50
$w.1 delete movable
set subjective { }
set objective { }
set assesment { }
set plan { }
generate"
$w.1 create window 300 50 -window $w.1.reset

button $w.1.but1 -text No -bg grey -fg black -height 1  -padx 0 -pady 0 -command "$w.1.mes2 config -bg gray -fg gray50
$w.1.mes4 config -bg red -fg yellow
$w.1.mes9 config -bg gray -fg gray50
lappend subjective {The patient is at his or her baseline.}
drawline $w.1 $w.1.mes2 $w.1.mes4
generate
after 1000 $w.1 yview moveto .075"
$w.1 create window 56 188 -window $w.1.but1 

button $w.1.but2 -text Yes -bg grey -fg black -height 1 -padx 0 -pady 0 -command "$w.1.mes2 config -bg gray -fg gray50
$w.1.mes9 config -bg red -fg yellow
$w.1.mes4 config -bg gray -fg gray50
drawline $w.1 $w.1.mes2 $w.1.mes9
lappend subjective {The patient is worse than usual.}
generate"
$w.1 create window 150 140 -window $w.1.but2

message $w.1.mes9 -text "See Asthma - Worse than usual.  Continue on MAP when at baseline" -bg gray -fg gray50 -aspect 150
$w.1 create window 250 145 -window $w.1.mes9 -tag $w.1.mes9

button $w.1.but10 -text "Go to Worse" -fg black -height 1 -padx 0 -pady 0 -command "Notebook:raise.page .top.n 1
drawline $w.1 $w.1.mes9 $w.1.but10
drawloop $w.1 $w.1.but10"
$w.1 create window 360  140 -window $w.1.but10 -tag $w.1.but10



message $w.1.mes4 -text "Is there a previous confirmed diagnosis (Dx) of asthma?" -bg gray -fg gray50 -aspect 200
$w.1 create window 69 245 -window $w.1.mes4 -tag $w.1.mes4

button $w.1.but3 -text Yes -bg grey -fg black -height 1 -padx 0 -pady 0 -command "$w.1.mes4 config -bg gray -fg gray50
$w.1.mes5 config -bg red -fg yellow
$w.1.mes11 config -bg gray -fg gray50
drawline $w.1 $w.1.mes4 $w.1.mes5
lappend subjective {There IS a previous confirmed diagnosis of asthma.}
after 1000 $w.1 yview moveto .15
generate"
$w.1 create window 59 293 -window $w.1.but3 

message $w.1.mes11 -text "See Asthma Diagnosis" -bg gray -fg gray50 -aspect 200
$w.1 create window 270 245 -window $w.1.mes11 -tag $w.1.mes11

button $w.1.but11 -text "No, or unsure" -bg grey -fg black -height 1 -padx 0 -pady 0 -command "$w.1.mes4 config -bg gray -fg gray50
$w.1.mes11 config -bg red -fg yellow
$w.1.mes5 config -bg gray -fg gray50
drawline $w.1 $w.1.mes4 $w.1.mes11
lappend subjective {There has NOT been a previous confirmed diagnosis of asthma.}
generate"
$w.1 create window 189 245 -window $w.1.but11 

button $w.1.but12 -text "Go to Diagnosis" -bg gray -fg black -height 1 -padx 0 -pady 0 -command "Notebook:raise.page .top.n 3
drawline $w.1 $w.1.mes11 $w.1.but12
drawloop $w.1 $w.1.but12"
$w.1 create window 360 260 -window $w.1.but12 -tag $w.1.but12

button $w.1.but21 -text "Go to Symptoms" -bg gray -fg black -height 1 -padx 0 -pady 0 -command "Notebook:raise.page .top.n 2
drawline $w.1 $w.1.mes11 $w.1.but21
drawloop $w.1 $w.1.but21"
$w.1 create window 368 232 -window $w.1.but21 -tag $w.1.but21



message $w.1.mes5 -text "Has the asthma been classified?" -bg gray -fg gray50 -aspect 200
$w.1 create window 54 335 -window $w.1.mes5 -tag $w.1.mes5

button $w.1.but4 -text Yes -bg grey -fg black -height 1 -padx 0 -pady 0 -command "$w.1.mes5 config -bg gray -fg gray50
$w.1.mes6 config -bg red -fg yellow
$w.1.mes12 config -bg gray -fg gray50
drawline $w.1 $w.1.mes5 $w.1.mes6
lappend subjective {The patient's asthma has been classified.}
after 1000 $w.1 yview moveto .225
generate"
$w.1 create window 59 378 -window $w.1.but4

message $w.1.mes12 -text "See Classification of Asthma - 1997 NHLBI guidelines." -bg gray -fg gray50 -aspect 200
$w.1 create window 270 335 -window $w.1.mes12 -tag $w.1.mes12

button $w.1.but13 -text "No, or unsure" -bg gray -fg black -height 1 -padx 0 -pady 0 -command "$w.1.mes5 config -bg gray -fg gray50
$w.1.mes12 config -bg red -fg yellow
$w.1.mes6 config -bg gray -fg gray50
drawline $w.1 $w.1.mes5 $w.1.mes12
lappend subjective {The patient's asthma has not previously been classified according to 1997 NHLBI guidelines.}
generate"
$w.1 create window 155 335 -window $w.1.but13

button $w.1.but14 -text "Go to Classification" -bg gray -fg black -height 1 -padx 0 -pady 0 -command "Notebook:raise.page .top.n 4
drawline $w.1 $w.1.mes12 $w.1.but14
drawloop $w.1 $w.1.but14"
$w.1 create window 405 335 -window $w.1.but14 -tag $w.1.but14


message $w.1.mes6 -text "Has the severity/frequency of the condition been determined? (Staging)" -bg gray -fg gray50 -aspect 200
$w.1 create window 80 435 -window $w.1.mes6 -tag $w.1.mes6

button $w.1.but5 -text Yes -bg grey -fg black -height 1 -padx 0 -pady 0 -command "$w.1.mes6 config -bg gray -fg gray50
$w.1.mes7 config -bg red -fg yellow
$w.1.mes13 config -bg gray -fg gray50
drawline $w.1 $w.1.mes6 $w.1.mes7
lappend subjective {The severity/frequency of the condition has been determined (Staged).}
after 1000 $w.1 yview moveto .3
generate"
$w.1 create window 79 493 -window $w.1.but5

message $w.1.mes13 -text "See Staging - 1997 NHLBI guidelines." -bg gray -fg gray50 -aspect 200
$w.1 create window 310 435 -window $w.1.mes13 -tag $w.1.mes13

button $w.1.but15 -text "No, or unsure" -bg gray -fg black -height 1 -padx 0 -pady 0 -command "$w.1.mes6 config -bg gray -fg gray50
$w.1.mes13 config -bg red -fg yellow
$w.1.mes7 config -bg gray -fg gray50
drawline $w.1 $w.1.mes6 $w.1.mes13
lappend subjective {The patient's ashtma has not yet been Staged according to NHLBI 1997 guidelines.}
generate"
$w.1 create window 207 435 -window $w.1.but15

button $w.1.but16 -text "Go to Staging" -bg gray -fg black -height 1 -padx 0 -pady 0 -command "Notebook:raise.page .top.n 5
drawline $w.1 $w.1.mes13 $w.1.but16
drawloop $w.1 $w.1.but16"
$w.1 create window 420 435 -window $w.1.but16 -tag $w.1.but16



message $w.1.mes7 -text "Is current Treatment plan appropriate for level of patient's asthma?" -bg gray -fg gray50 -aspect 200
$w.1 create window 79 545 -window $w.1.mes7 -tag $w.1.mes7

button $w.1.but6 -text Yes -bg gray -fg black -height 1 -padx 0 -pady 0 -command "$w.1.mes7 config -bg gray -fg gray50
$w.1.mes14 config -bg gray -fg gray50
$w.1.mes8 config -bg red -fg yellow
drawline $w.1 $w.1.mes7 $w.1.mes8
lappend assesment {The current Treatment plan is appropriate for the level of the patient's asthma.}
after 1000 $w.1 yview moveto .375
generate " 
$w.1 create window 79 600 -window $w.1.but6

message $w.1.mes14 -text "See Treatment... Med. Checklist" -bg gray -fg gray50 -aspect 200
$w.1 create window 310 545 -window $w.1.mes14 -tag $w.1.mes14

button $w.1.but17 -text "No, unsure" -bg gray -fg black -height 1 -padx 0 -pady 0 -command "$w.1.mes7 config -bg gray -fg gray50
$w.1.mes14 config -fg yellow -bg red
$w.1.mes8 config -bg gray -fg gray50
drawline $w.1 $w.1.mes7 $w.1.mes14
lappend subjective {The current treatment plan is reviewed and found to not be complete for the level of the patient's asthma.}
generate"
$w.1 create window 207 545 -window $w.1.but17 

button $w.1.but18 -text "Go to Treatment" -bg gray -fg black -height 1 -padx 0 -pady 0 -command "Notebook:raise.page .top.n 6
drawline $w.1 $w.1.mes14 $w.1.but18
drawloop $w.1 $w.1.but18"
$w.1 create window 430 545 -window $w.1.but18 -tag $w.1.but18


message $w.1.mes8 -text "Has the patient been Educated? Has action plan? Trigger list reviewed?" -bg gray -fg gray50 -aspect 200
$w.1 create window 79 650 -window $w.1.mes8 -tag $w.1.mes8

button $w.1.but7 -text Yes -bg gray -fg black -height 1 -padx 0 -pady 0 -command "$w.1.mes8 config -bg gray -fg gray50
$w.1.mes15 config -bg gray -fg gray50
$w.1.mes10 config -bg red -fg yellow
drawline $w.1 $w.1.mes8 $w.1.mes10
lappend assesment {The patient has been educated. The action plan has been reviewed. The trigger list has been reviewed.}
lappend plan {Continue follow-up with the primary care provider.}
after 1000 $w.1 yview moveto .45
generate"
$w.1 create window 79 700 -window $w.1.but7

message $w.1.mes15 -text "See Asthma - Pt. Education" -bg gray -fg gray50 -aspect 200
$w.1 create window 310 650 -window $w.1.mes15 -tag $w.1.mes15

button $w.1.but19 -text "No, unsure" -bg gray -fg black -height 1 -padx 0 -pady 0 -command "$w.1.mes8 config -bg gray -fg gray50
$w.1.mes15 config -bg red -fg yellow
$w.1.mes10 config -bg gray -fg gray50
drawline $w.1 $w.1.mes8 $w.1.mes15
lappend subjective {The patient does not have an action plan and need a review of the trigger list.}
generate"
$w.1 create window 207 650 -window $w.1.but19 

button $w.1.but20 -text "Go to Pt. Ed." -bg gray -fg black -height 1 -padx 0 -pady 0 -command "Notebook:raise.page .top.n 7
drawline $w.1 $w.1.mes15 $w.1.but20
drawloop $w.1 $w.1.but20"
$w.1 create window 430 650 -window $w.1.but20 -tag $w.1.but20



message $w.1.mes10 -text "Continue follow-up with the primary care provider." -bg gray -fg gray50 -aspect 200
$w.1 create window 79 755 -window $w.1.mes10 -tag $w.1.mes10



$w.1 bind movable  <Button-3> {CanvasMark %x %y %W}
$w.1 bind movable  <B3-Motion> {CanvasDrag %x %y %W}

###############################################################################################
# Asthma Worse notebook page

set r [Notebook:frame .top.n Worse]

canvas $r.1 -relief groove -bg black -yscrollcommand "$r.sb1 set" -xscrollcommand "$r.sb2 set" -scrollregion {0 0 1200 1200}
scrollbar $r.sb2 -orient horizontal -command "$r.1 xview"
pack $r.sb2 -side bottom -fill x
scrollbar $r.sb1 -orient vertical -command "$r.1 yview"
pack $r.sb1 -side right -fill y    
pack $r.1 -side left  -fill both -expand 1

    Notebook:create .top.n.f1.1.sub -pages {Algorithm  Table} -width 725  -height 525
    pack .top.n.f1.1.sub
    
    set q1 [Notebook:frame .top.n.f1.1.sub Algorithm]
    canvas $q1.1 -relief groove -bg black  -yscrollcommand "$q1.sb1 set" -xscrollcommand "$q1.sb2 set" -scrollregion {0 0 1200 1200}
    scrollbar $q1.sb2 -orient horizontal -command "$q1.1 xview"
    pack $q1.sb2 -side bottom -fill x
    scrollbar $q1.sb1 -orient vertical -command "$q1.1 yview"
    pack $q1.sb1 -side right -fill y
    pack $q1.1 -side left  -fill both -expand 1



message $q1.1.mes1 -text "Shortness of Breath with Hx of Asthma diagnosis..... if unsure see Shortness of Breath (ER) or Ashtma Dx?" \
 -bg tan -fg black -aspect 150
$q1.1 create window 74 50 -window $q1.1.mes1

message $q1.1.mes2 -text "Assess CALMLY..... Is the patient able to talk in 3-4 word phrases?" -bg red -fg yellow -aspect 250
$q1.1 create window 74 150 -window $q1.1.mes2

message $q1.1.mes3 -text "Oxygen, Monitor, IV.  Mental Status Change or severe resp. distress?" \
-bg gray -fg gray50
$q1.1 create window 305 150 -window $q1.1.mes3

button $q1.1.but1 -text "Yes" -padx 0 -pady 0 -command "$q1.1.mes2 config -bg gray -fg gray50
$q1.1.mes3 config -bg gray -fg gray50
lappend objective {The patient is ABLE to talk in 3 to 4 word phrases}
generate"
$q1.1 create window 79 200 -window $q1.1.but1

button $q1.1.but2 -text "No" -padx 0 -pady 0 -command "$q1.1.mes3 config -bg red -fg yellow
$q1.1.mes2 config -bg gray -fg gray50
lappend objective {The patient is UNABLE to talk in 3 to 4 word phrases}
drawline $q1.1 $q1.1.mes2 $q1.1.mes3
generate "
$q1.1 create window 205 150 -window $q1.1.but2
#******************************************************************
    set p1 [Notebook:frame .top.n.f1.1.sub Table]
    canvas $p1.1 -relief groove -bg black  -yscrollcommand "$p1.sb1 set" -xscrollcommand "$p1.sb2 set" -scrollregion {0 0 1200 1200}
    scrollbar $p1.sb2 -orient horizontal -command "$p1.1 xview"
    pack $p1.sb2 -side bottom -fill x
    scrollbar $p1.sb1 -orient vertical -command "$p1.1 yview"
    pack $p1.sb1 -side right -fill y
    pack $p1.1 -side left  -fill both -expand 1
 
      label $p1.1.label1 -bg black -fg yellow -text "SEVERITY" 
       $p1.1 create window 280 20 -window $p1.1.label1 
       frame $p1.1.frame -borderwidth 0 
       $p1.1 create window 250 50 -window $p1.1.frame -anchor nw

          scale $p1.1.frame.scale  -fg red -bg black -borderwidth 3 -orient vertical -length 600 -from 100 -to 0 -relief sunken \
             -command "setHeight $p1.1.frame.canvas" -tickinterval 20 -variable severity  -troughcolor black -width 7 
          canvas $p1.1.frame.canvas -width 50 -height 50 -bg black -bd 0 -highlightthickness 0
          $p1.1.frame.canvas create polygon 0 0 1 1 2 2 -fill SeaGreen3 -tags poly
          $p1.1.frame.canvas create line 0 0 1 1 2 2 0 0 -fill yellow -tags line
           #$w.frame.canvas create polygon 0 0 1 1 2 2 -fill SeaGreen3 -tags poly
           #$w.frame.canvas create line 0 0 1 1 2 2 0 0 -fill yellow -tags line

      pack $p1.1.frame.scale -side left -anchor ne
      pack $p1.1.frame.canvas -side left -anchor nw -fill y
      $p1.1.frame.scale set 0

      proc setHeight {w height} {
         global p1   
         set height [expr -(6 * $height)]
         incr height 21
         set y2 [expr $height + 30]
         if {$y2 > 21} {
         set y2 21
         }
      set y2 [expr $y2 +575]
      set height [expr $height + 575]
      #$w coords poly 15 20 35 20 35 $y2 45 $y2 25 $height 5 $y2 15 $y2 15 20
      #$w coords line 15 20 35 20 35 $y2 45 $y2 25 $height 5 $y2 15 $y2 15 20
      $p1.1.frame.canvas coords poly 15 595 35 595 35 $y2 45 $y2 25 $height 5 $y2 15 $y2 15 595
      $p1.1.frame.canvas coords line 15 595 35 595 35 $y2 45 $y2 25 $height 5 $y2 15 $y2 15 595

}

      message $p1.1.mes1 -bg red -fg yellow -aspect 200 -relief groove -text "Fever? Chest Pain?"
      $p1.1 create window 5 5 -window $p1.1.mes1 -anchor nw
   
      button $p1.1.but1 -height 1 -padx 0 -pady 0 -text "Yes" -command {$p1.1.mes1 config -bg gray -fg gray50
      $p1.1.mes2 config -bg red -fg yellow
      for {set x 1} {$x < 9} {incr x} {
      $p1.1.symptoms.$x config -state disabled 
      $p1.1.lab.$x config -state disabled 
      } 
      for {set x 1} {$x < 11} {incr x} {
      $p1.1.physical.$x config -state disabled
      }
      } 
      $p1.1 create window 75 15 -window $p1.1.but1 -anchor nw

      message $p1.1.mes2 -bg gray -fg grey50 -aspect 200 -relief groove -text "Suspect other etiologies.."
      $p1.1 create window 130 15 -window $p1.1.mes2 -anchor nw

      button $p1.1.but2 -height 1 -padx 0 -pady 0 -text "No" -command {$p1.1.mes1 config -bg gray -fg gray50
      $p1.1.mes2 config -bg gray -fg gray50
      for {set x 1} {$x < 9} {incr x} {
      $p1.1.symptoms.$x config -state normal 
      $p1.1.lab.$x config -state normal 
      }
      $p1.1.physical.1 config -state normal
      for {set x 5} {$x < 11} {incr x} {
      $p1.1.physical.$x config -state normal 
      }
      }
      $p1.1 create window 23 69 -window $p1.1.but2 -anchor nw


      frame $p1.1.symptoms -relief sunken -borderwidth 5 
      $p1.1 create window 5 108 -window $p1.1.symptoms -anchor nw
      label $p1.1.symptoms.label -text "Symptoms/History";pack $p1.1.symptoms.label
      checkbutton $p1.1.symptoms.1 -text "Severe SOB?"  -variable symptom1  -command {
         if {$symptom1 == 1} {$p1.1.frame.scale set [expr $severity + 10]
         checkseverity
         } else {
         $p1.1.frame.scale set [expr $severity - 10]
         checkseverity
         }} \
         -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled
      pack $p1.1.symptoms.1 -side top -anchor w
 
      checkbutton $p1.1.symptoms.2 -text "Can't talk at all?"  -variable symptom2 -command {
         if {$symptom2 == 1} {$p1.1.frame.scale set [expr $severity + 10]
         checkseverity
         } else {
         $p1.1.frame.scale set [expr $severity - 10]
         checkseverity
         }} \
         -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled
      pack $p1.1.symptoms.2 -side top -anchor w
      checkbutton $p1.1.symptoms.3 -text "Altered Mental Status?"  -variable symptom3 -command {
         if {$symptom3 == 1} {$p1.1.frame.scale set [expr $severity + 10]
         checkseverity
         } else {$p1.1.frame.scale set [expr $severity - 10]
        checkseverity
        }} \
         -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled
      pack $p1.1.symptoms.3 -side top -anchor w
      checkbutton $p1.1.symptoms.4 -text "Audible Wheeze?"  -variable symptom4 -command {
         if {$symptom4 == 1} {$p1.1.frame.scale set [expr $severity + 5]
         checkseverity
       } else {$p1.1.frame.scale set [expr $severity - 5]
       checkseverity
       }} \
        -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled
      pack $p1.1.symptoms.4 -side top -anchor w
      checkbutton $p1.1.symptoms.5 -text "Prev. Hospitalizations?"  -variable symptom5 -command {
         if {$symptom5 == 1} {$p1.1.frame.scale set [expr $severity + 10]
         checkseverity
         } else {$p1.1.frame.scale set [expr $severity - 10]
         checkseverity
         }} \
        -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled
     pack $p1.1.symptoms.5 -side top -anchor w
      checkbutton $p1.1.symptoms.6 -text "Prev. Intubations?"  -variable symptom6 -command {
         if {$symptom6 == 1} {$p1.1.frame.scale set [expr $severity + 10]
         checkseverity
        } else {$p1.1.frame.scale set [expr $severity - 10]
      checkseverity
      }} \
        -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled
      pack $p1.1.symptoms.6 -side top -anchor w
      checkbutton $p1.1.symptoms.7 -text ">4 Tx's MD/HHN?"  -variable symptom7 -command {
         if {$symptom7 == 1} {$p1.1.frame.scale set [expr $severity + 5]
      checkseverity
      } else {$p1.1.frame.scale set [expr $severity - 5]
      checkseverity
      }} \
        -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled
      pack $p1.1.symptoms.7 -side top -anchor w
     checkbutton $p1.1.symptoms.8 -text "Smoker/COPD?"  -variable symptom8 -command {
         if {$symptom8 == 1} {$p1.1.frame.scale set [expr $severity + 10]
       checkseverity
       } else {$p1.1.frame.scale set [expr $severity - 10]
      checkseverity
      }} \
        -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled
      pack $p1.1.symptoms.8 -side top -anchor w

      frame $p1.1.physical -relief sunken -borderwidth 5
      $p1.1 create window 5 325 -window $p1.1.physical -anchor nw
      label $p1.1.physical.label -text "Physical Exam";pack $p1.1.physical.label
      checkbutton $p1.1.physical.1 -text "Trouble talking?"  -variable physical1  -command {   
      $p1.1.physical.2 config -state normal;$p1.1.physical.3 config -state normal;$p1.1.physical.4 config -state normal
         } \
         -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled
      pack $p1.1.physical.1 -side top -anchor w
      checkbutton $p1.1.physical.2 -text "2 word complete sentences"  -variable physical2  -command {
         if {$physical2 == 1} {$p1.1.frame.scale set [expr $severity + 10]
       checkseverity
       } else {$p1.1.frame.scale set [expr $severity - 10]
       checkseverity
       }} \
         -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled
      pack $p1.1.physical.2 -side top -anchor w
     checkbutton $p1.1.physical.3 -text "4 word complete sentences"  -variable physical3  -command {
         if {$physical3 == 1} {$p1.1.frame.scale set [expr $severity + 8]
     checkseverity
     } else {$p1.1.frame.scale set [expr $severity - 8]
      checkseverity
      }} \
         -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled
      pack $p1.1.physical.3 -side top -anchor w
     checkbutton $p1.1.physical.4 -text "6 word complete sentences"  -variable physical4  -command {
         if {$physical4 == 1} {$p1.1.frame.scale set [expr $severity + 6]
      checkseverity
      } else {$p1.1.frame.scale set [expr $severity - 6]
      checkseverity
      }} \
         -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled
      pack $p1.1.physical.4 -side top -anchor w
     checkbutton $p1.1.physical.5 -text "Accessory muscle use?" -variable physical5  -command {
         if {$physical5 == 1} {$p1.1.frame.scale set [expr $severity + 8]
     checkseverity
     } else {$p1.1.frame.scale set [expr $severity - 8]
     checkseverity
     }} \
         -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled
      pack $p1.1.physical.5 -side top -anchor w
     checkbutton $p1.1.physical.6 -text "Altered mental status?"  -variable physical6  -command {
         if {$physical6 == 1} {$p1.1.frame.scale set [expr $severity + 10]
     checkseverity
     } else {$p1.1.frame.scale set [expr $severity - 10]
     checkseverity
     }} \
         -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled               
      pack $p1.1.physical.6 -side top -anchor w
     checkbutton $p1.1.physical.7 -text "Heart Rate > 100 ?"  -variable physical7  -command {
         if {$physical7 == 1} {$p1.1.frame.scale set [expr $severity + 7]
     checkseverity
     } else {$p1.1.frame.scale set [expr $severity - 7]
     checkseverity
     }} \
         -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled
      pack $p1.1.physical.7 -side top -anchor w
     checkbutton $p1.1.physical.8 -text "Resp. Rate > 30 ?"  -variable physical8  -command {
         if {$physical8 == 1} {$p1.1.frame.scale set [expr $severity + 7]
     checkseverity
     } else {$p1.1.frame.scale set [expr $severity - 7]
     checkseverity
     }} \
         -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled
      pack $p1.1.physical.8 -side top -anchor w
     checkbutton $p1.1.physical.9 -text "Age > 35 ?"  -variable physical9  -command {
         if {$physical9 == 1} {$p1.1.frame.scale set [expr $severity + 5]
     checkseverity
     } else {$p1.1.frame.scale set [expr $severity - 5]
     checkseverity
     }} \
         -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled
      pack $p1.1.physical.9 -side top -anchor w
    checkbutton $p1.1.physical.10 -text "Auscultation - wheeze"  -variable physical10  -command {
         if {$physical10 == 1} {$p1.1.frame.scale set [expr $severity + 10]
     checkseverity
     } else {$p1.1.frame.scale set [expr $severity - 10]
     checkseverity
     }} \
         -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled
      pack $p1.1.physical.10 -side top -anchor w
 
      frame $p1.1.lab -relief sunken -borderwidth 5
      $p1.1 create window 5 572 -window $p1.1.lab -anchor nw
      label $p1.1.lab.label -text "Labs";pack $p1.1.lab.label
      checkbutton $p1.1.lab.1 -text "Pulse ox. < 90%"  -variable lab1  -command {
       if {$lab1 == 1} {$p1.1.frame.scale set [expr $severity + 10]
       $p1.1.lab.2 config -state disabled
       $p1.1.lab.3 config -state disabled
       $p1.1.lab.4 config -state disabled
       $p1.1.lab.5 config -state disabled
       $p1.1.lab.6 config -state disabled
       $p1.1.lab.7 config -state disabled
       $p1.1.lab.8 config -state disabled 
       checkseverity
       } else {$p1.1.frame.scale set [expr $severity - 10]
       $p1.1.lab.2 config -state normal
       $p1.1.lab.3 config -state normal
       $p1.1.lab.4 config -state normal
       $p1.1.lab.5 config -state normal 
       $p1.1.lab.6 config -state normal
       $p1.1.lab.7 config -state normal
       $p1.1.lab.8 config -state normal
       checkseverity
         }
         } \
         -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled
      pack $p1.1.lab.1 -side top -anchor w

      checkbutton $p1.1.lab.2 -text "Pulse ox. < 95%"  -variable lab2  -command {
         if {$lab2 == 1} {$p1.1.frame.scale set [expr $severity + 5]
        $p1.1.lab.1 config -state disabled
        $p1.1.lab.4 config -state disabled
        $p1.1.lab.5 config -state disabled
        $p1.1.lab.6 config -state disabled
        $p1.1.lab.7 config -state disabled
        $p1.1.lab.8 config -state disabled
        checkseverity
        } else {$p1.1.frame.scale set [expr $severity - 5]
        $p1.1.lab.1 config -state normal
        $p1.1.lab.3 config -state normal
        $p1.1.lab.4 config -state normal
        $p1.1.lab.5 config -state normal
        $p1.1.lab.6 config -state normal
        $p1.1.lab.7 config -state normal
        $p1.1.lab.8 config -state normal
        checkseverity
        }
        } \
         -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled
      pack $p1.1.lab.2 -side top -anchor w

      checkbutton $p1.1.lab.3 -text "Peak Flow (WPF) <60% predicted"  -variable lab3  -command {
         if {$lab3 == 1} {$p1.1.frame.scale set [expr $severity + 10]
         $p1.1.lab.1 config -state disabled
         $p1.1.lab.4 config -state disabled
         $p1.1.lab.5 config -state disabled
         $p1.1.lab.6 config -state disabled
         $p1.1.lab.7 config -state disabled
         $p1.1.lab.8 config -state disabled
         checkseverity
       } else {$p1.1.frame.scale set [expr $severity - 10]
        $p1.1.lab.1 config -state normal
        $p1.1.lab.2 config -state normal
        $p1.1.lab.4 config -state normal
        $p1.1.lab.5 config -state normal
        $p1.1.lab.6 config -state normal
        $p1.1.lab.7 config -state normal
        $p1.1.lab.8 config -state normal
        checkseverity
         }
         } \
         -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled
      pack $p1.1.lab.3 -side top -anchor w

      checkbutton $p1.1.lab.4 -text "Peak Flow <80% predicted"  -variable lab4  -command {
         if {$lab4 == 1} {$p1.1.frame.scale set [expr $severity + 5]
         $p1.1.lab.1 config -state disabled
         $p1.1.lab.2 config -state disabled
         $p1.1.lab.3 config -state disabled
         checkseverity
       } else {$p1.1.frame.scale set [expr $severity - 10]
        $p1.1.lab.1 config -state normal 
        $p1.1.lab.2 config -state normal 
        $p1.1.lab.3 config -state normal
        $p1.1.lab.5 config -state normal
        $p1.1.lab.6 config -state normal
        $p1.1.lab.7 config -state normal
        $p1.1.lab.8 config -state normal
        checkseverity
         }
         } \
         -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled
      pack $p1.1.lab.4 -side top -anchor w

      checkbutton $p1.1.lab.5 -text "ABG pO2 <60"  -variable lab5  -command {
         if {$lab5 == 1} {$p1.1.frame.scale set [expr $severity + 10]
         $p1.1.lab.1 config -state disabled
         $p1.1.lab.2 config -state disabled
         $p1.1.lab.3 config -state disabled
         checkseverity
       } else {$p1.1.frame.scale set [expr $severity - 10]
        $p1.1.lab.1 config -state normal
        $p1.1.lab.2 config -state normal
        $p1.1.lab.3 config -state normal  
        $p1.1.lab.4 config -state normal
        $p1.1.lab.6 config -state normal
        $p1.1.lab.7 config -state normal
        $p1.1.lab.8 config -state normal
        checkseverity
         }
         } \
         -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled
      pack $p1.1.lab.5 -side top -anchor w 

      checkbutton $p1.1.lab.6 -text "ABG PO2 <80"  -variable lab6  -command {
         if {$lab6 == 1} {$p1.1.frame.scale set [expr $severity + 5]
         $p1.1.lab.1 config -state disabled
         $p1.1.lab.2 config -state disabled
         $p1.1.lab.3 config -state disabled
         checkseverity
       } else {$p1.1.frame.scale set [expr $severity - 5]
        $p1.1.lab.1 config -state normal  
        $p1.1.lab.2 config -state normal
        $p1.1.lab.3 config -state normal
        $p1.1.lab.4 config -state normal
        $p1.1.lab.5 config -state normal
        $p1.1.lab.7 config -state normal
        $p1.1.lab.8 config -state normal
        checkseverity
         }
         } \
         -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled
      pack $p1.1.lab.6 -side top -anchor w

      checkbutton $p1.1.lab.7 -text "Sputum - Colored"  -variable lab7  -command {
         if {$lab7 == 1} {$p1.1.frame.scale set [expr $severity + 10]
         $p1.1.lab.1 config -state disabled
         $p1.1.lab.2 config -state disabled
         $p1.1.lab.3 config -state disabled
       } else {$p1.1.frame.scale set [expr $severity - 10]
        $p1.1.lab.1 config -state normal
        $p1.1.lab.2 config -state normal
        $p1.1.lab.3 config -state normal
        $p1.1.lab.4 config -state normal   
        $p1.1.lab.5 config -state normal
        $p1.1.lab.6 config -state normal
        $p1.1.lab.8 config -state normal   
         }
         } \
         -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled
      pack $p1.1.lab.7 -side top -anchor w

      checkbutton $p1.1.lab.8 -text "Sputum - White"  -variable lab8  -command {
         if {$lab8 == 1} {$p1.1.frame.scale set [expr $severity + 5]
         $p1.1.lab.1 config -state disabled
         $p1.1.lab.2 config -state disabled
         $p1.1.lab.3 config -state disabled
         checkseverity
       } else {$p1.1.frame.scale set [expr $severity - 5]
        $p1.1.lab.1 config -state normal
        $p1.1.lab.2 config -state normal
        $p1.1.lab.3 config -state normal   
        $p1.1.lab.4 config -state normal   
        $p1.1.lab.5 config -state normal   
        $p1.1.lab.6 config -state normal
        $p1.1.lab.7 config -state normal
        checkseverity
         }
         } \
         -font -*-courier-*-r-*-*-*-100-*-*-*-*-*-* -state disabled
      pack $p1.1.lab.8 -side top -anchor w 

      proc checkseverity {} {
           global severity p1
        if {$severity > 0 && $severity <= 6.5} {
           $p1.1.mild config -fg red
           $p1.1.calm config -fg red
        } elseif {$severity > 6.5} {
           $p1.1.mild config -fg blue
           $p1.1.calm config -fg blue
           } else {
           $p1.1.mild config -fg gray50
           $p1.1.calm config -fg gray50
           }
        if {$severity > 6.5 && $severity <= 13} {
           $p1.1.triggers config -fg red
         } elseif {$severity > 13} {
           $p1.1.triggers config -fg blue
           } else {
           $p1.1.triggers config -fg gray50
           }
         if {$severity > 13 && $severity <= 19.5} {
           $p1.1.bagonists1 config -fg red
           $p1.1.home config -fg red
         } elseif {$severity > 19.5} {
           $p1.1.bagonists1 config -fg blue
           $p1.1.home config -fg blue
           } else {
           $p1.1.bagonists1 config -fg gray50
           $p1.1.home config -fg gray50
           }
         if {$severity > 19.5 && $severity <= 26} {
           $p1.1.oxygen config -fg red
          } elseif  {$severity > 26} {
           $p1.1.oxygen config -fg blue
           } else {
           $p1.1.oxygen config -fg gray50
           }
         if {$severity > 26 && $severity <= 32.5} {
           $p1.1.epinephrine config -fg red
           $p1.1.closefollowup config -fg red
          } elseif {$severity > 32.5} {
           $p1.1.epinephrine config -fg blue
           $p1.1.closefollowup config -fg blue
           } else {
           $p1.1.epinephrine config -fg gray50
           $p1.1.closefollowup config -fg gray50
           }
         if {$severity > 32.5 && $severity <=39} {
           $p1.1.bagonists2 config -fg red
           } elseif {$severity > 39} {
           $p1.1.bagonists2 config -fg blue
           } else {
           $p1.1.bagonists2 config -fg gray50
           }
          if {$severity > 39 && $severity <= 45.5} { 
           $p1.1.steroids config -fg red
           $p1.1.prolongedervisit config -fg red
           } elseif  {$severity > 45.5} {
           $p1.1.steroids config -fg blue
           $p1.1.prolongedervisit config -fg blue
           } else {
           $p1.1.steroids config -fg gray50
           $p1.1.prolongedervisit config -fg gray50
           }
          if {$severity > 45.5 && $severity <= 52} {
           $p1.1.continuousneb config -fg red
          } elseif {$severity > 52} {
           $p1.1.continuousneb config -fg blue
          } else {
           $p1.1.continuousneb config -fg gray50
           }
          if {$severity > 52 && $severity <= 58.5} {
           $p1.1.ivfluids config -fg red
            $p1.1.hospitalize config -fg red
          } elseif {$severity > 58.5} {
            $p1.1.ivfluids config -fg blue
            $p1.1.hospitalize config -fg blue
          } else {
            $p1.1.ivfluids config -fg gray50
            $p1.1.hospitalize config -fg gray50
          }
         if {$severity > 58.5 && $severity <= 65} {
         $p1.1.antibiotics config -fg red
         } elseif  {$severity > 65} {
         $p1.1.antibiotics config -fg blue
         } else {
         $p1.1.antibiotics config -fg gray50
         }
         if {$severity > 65 && $severity <= 71.5} { 
         $p1.1.aminophylline config -fg red
         $p1.1.tcaadmit config -fg red
         } elseif {$severity > 71.5} {
         $p1.1.aminophylline config -fg blue
         $p1.1.tcaadmit config -fg blue
         } else {
         $p1.1.aminophylline config -fg gray50
         $p1.1.tcaadmit config -fg gray50
         }
         if {$severity > 71.5 && $severity <= 78} {
         $p1.1.morphine config -fg red
         } elseif {$severity > 78} {
         $p1.1.morphine config -fg blue
         } else {
         $p1.1.morphine config -fg gray50
         }
         if {$severity > 78 && $severity <= 84.5} {
          $p1.1.cpap config -fg red
          $p1.1.icuadmit config -fg red
         } elseif {$severity > 84.5} {
          $p1.1.cpap config -fg blue    
         $p1.1.icuadmit config -fg blue
         } else {
         $p1.1.cpap config -fg gray50
         $p1.1.icuadmit config -fg gray50
         }
         if {$severity > 84.5 && $severity <= 91} {
         $p1.1.magnesium config -fg red
         $p1.1.statusasthmaticus config -fg red
         } elseif {$severity > 91 } {
         $p1.1.magnesium config -fg blue
         $p1.1.statusasthmaticus config -fg blue
         } else {
         $p1.1.magnesium config -fg gray50
         $p1.1.statusasthmaticus config -fg gray50
         }
         if {$severity > 91 } {
          $p1.1.intubation config -fg red
          $p1.1.severe config -fg red
         } else {
          $p1.1.intubation config -fg grey50
          $p1.1.severe config -fg grey50
          }
      }

label $p1.1.intubation -text Intubation -bg black -fg grey50
$p1.1 create window 400 50 -window $p1.1.intubation -anchor nw

label $p1.1.severe -text Severe -bg black -fg gray50
$p1.1 create window 550 50 -window $p1.1.severe -anchor nw

label $p1.1.magnesium -text "Mg 1-2 gm. IV" -bg black -fg grey50
$p1.1 create window 400 90 -window $p1.1.magnesium -anchor nw

label $p1.1.statusasthmaticus -text "Status Asthmaticus" -bg black -fg grey50
$p1.1 create window 550 90 -window $p1.1.statusasthmaticus -anchor nw

label $p1.1.cpap -text "CPAP" -bg black -fg grey50
$p1.1 create window 400 130 -window $p1.1.cpap -anchor nw

label $p1.1.icuadmit -text "ICU Admit" -bg black -fg grey50
$p1.1 create window 550 130 -window $p1.1.icuadmit -anchor nw

label $p1.1.morphine -text "Morphine or valium" -bg black -fg grey50
$p1.1 create window 550 170 -window $p1.1.morphine -anchor nw

label $p1.1.aminophylline -text "Aminophylline drip" -bg black -fg grey50
$p1.1 create window 400 200 -window $p1.1.aminophylline -anchor nw

label $p1.1.tcaadmit -text "TCA Admit (step down)" -bg black -fg grey50
$p1.1 create window 550 200 -window $p1.1.tcaadmit -anchor nw

label $p1.1.antibiotics -text "?Antibiotics (po/IV)" -bg black -fg grey50
$p1.1 create window 400 240 -window $p1.1.antibiotics -anchor nw

label $p1.1.ivfluids -text "IV fluids" -bg black -fg grey50
$p1.1 create window 400 280 -window $p1.1.ivfluids -anchor nw

label  $p1.1.hospitalize -text "Hospitalize" -bg black -fg grey50
$p1.1 create window 550 280 -window $p1.1.hospitalize -anchor nw

label $p1.1.continuousneb -text "Continuous Neb.Tx.(q.2h)" -bg black -fg grey50
$p1.1 create window 400 320 -window $p1.1.continuousneb -anchor nw

label $p1.1.steroids -text "Steroids (po/IV)" -bg black -fg grey50
$p1.1 create window 400 360 -window $p1.1.steroids -anchor nw

label $p1.1.prolongedervisit -text "Prolonged ER visit" -bg black -fg grey50
$p1.1 create window 550 360 -window $p1.1.prolongedervisit -anchor nw

label $p1.1.bagonists2 -text "Beta-agonists (more)" -bg black -fg grey50
$p1.1 create window 400 400 -window $p1.1.bagonists2 -anchor nw

label $p1.1.epinephrine -text "Epinephrine SQ?" -bg black -fg grey50
$p1.1 create window 400 440 -window $p1.1.epinephrine -anchor nw

label $p1.1.closefollowup -text "Home with close follow-up" -bg black -fg grey50
$p1.1 create window 550 440 -window $p1.1.closefollowup -anchor nw

label $p1.1.oxygen -text "Oxygen" -bg black -fg grey50
$p1.1 create window 400 480 -window $p1.1.oxygen -anchor nw

label $p1.1.bagonists1 -text "Beta-agonists" -bg black -fg grey50
$p1.1 create window 400 520 -window $p1.1.bagonists1 -anchor nw

label $p1.1.home -text "Home" -bg black -fg grey50
$p1.1 create window 550 520 -window $p1.1.home -anchor nw

label $p1.1.triggers -text "Check Triggers" -bg black -fg grey50
$p1.1 create window 400 560 -window $p1.1.triggers -anchor nw

label $p1.1.calm -text "Calm Patient" -bg black -fg grey50
$p1.1 create window 400 600 -window $p1.1.calm -anchor nw

label $p1.1.mild -text "Mild" -bg black -fg grey50
$p1.1 create window 550 600 -window $p1.1.mild -anchor nw
################################################################################################
#
set s [Notebook:frame .top.n Symptoms]

canvas $s.1 -relief groove -bg black -xscrollcommand "$s.sb2 set" -yscrollcommand "$s.sb1 set"  -scrollregion {0 0 1200 1200}
scrollbar $s.sb2 -orient horizontal -command "$s.1 xview"
pack $s.sb2 -side bottom -fill x
scrollbar $s.sb1 -orient vertical -command "$s.1 yview"
pack $s.sb1 -side right -fill y
pack $s.1 -side left  -fill both -expand 1

    Notebook:create .top.n.f2.1.sub -pages {Cough Wheeze SOB} -width 725  -height 525
    pack .top.n.f2.1.sub
    
    set q [Notebook:frame .top.n.f2.1.sub Cough]
    canvas $q.1 -relief groove -bg black  -yscrollcommand "$q.sb1 set" -xscrollcommand "$q.sb2 set" -scrollregion {0 0 1200 1200}
    scrollbar $q.sb2 -orient horizontal -command "$q.1 xview"
    pack $q.sb2 -side bottom -fill x
    scrollbar $q.sb1 -orient vertical -command "$q.1 yview"
    pack $q.sb1 -side right -fill y
    pack $q.1 -side left  -fill both -expand 1

    set p [Notebook:frame .top.n.f2.1.sub Wheeze]
    canvas $p.1 -relief groove -bg black  -yscrollcommand "$p.sb1 set" -xscrollcommand "$p.sb2 set" -scrollregion {0 0 1200 1200}
    scrollbar $p.sb2 -orient horizontal -command "$p.1 xview"
    pack $p.sb2 -side bottom -fill x
    scrollbar $p.sb1 -orient vertical -command "$p.1 yview"
    pack $p.sb1 -side right -fill y
    pack $p.1 -side left  -fill both -expand 1

    set o [Notebook:frame .top.n.f2.1.sub SOB]
    canvas $o.1 -relief groove -bg black  -yscrollcommand "$o.sb1 set" -xscrollcommand "$o.sb2 set" -scrollregion {0 0 1200 1200}
    scrollbar $o.sb2 -orient horizontal -command "$o.1 xview"
    pack $o.sb2 -side bottom -fill x
    scrollbar $o.sb1 -orient vertical -command "$o.1 yview"
    pack $o.sb1 -side right -fill y
    pack $o.1 -side left  -fill both -expand 1


######################################################################################################################
set t [Notebook:frame .top.n Diagnosis]

canvas $t.1 -relief groove -bg black -yscrollcommand "$t.sb1 set" -xscrollcommand "$t.sb2 set" -scrollregion {0 0 1200 1200}
scrollbar $t.sb2 -orient horizontal -command "$t.1 xview"
pack $t.sb2 -side bottom -fill x 
scrollbar $t.sb1 -orient vertical -command "$t.1 yview"
pack $t.sb1 -side right -fill y
pack $t.1 -side left  -fill both -expand 1

message $t.1.mes1  -text "Have Symptoms (Sxs) been present at least two times previously?"  -fg black -bg goldenrod \
-aspect 150
$t.1 create window 62 50 -tags movable -window $t.1.mes1

bind $t.1.mes1 <Button-1> {frame .frame06 -bg red;place .frame06 -x 58 -y 50 -height 208 -width 308
message .frame06.box06message -aspect 150 -bg ivory -text "The Diagnosis (Dx) should be made by primary care physicians
familiar with the patient, and not in the ER during an initial acute setting.  It can certainly be suspected and would be
treated the same way.  Patient in the ER should always be referred for primary care follow-up."
place .frame06.box06message -x 4 -y 4 -height 200 -width 300 -anchor nw -bordermode ignore
bind .frame06.box06message <Button-1> {destroy .frame06}}

message $t.1.mes2 -text "?Associated Sx Weight loss? Sputum production? \n>60 pk. yr. smoker?" -bg red -fg yellow -aspect 150
$t.1 create window 62 145  -window $t.1.mes2
 
bind $t.1.mes2 <Button-1> {frame .frame07 -bg red;place .frame07 -x 53 -y 145 -height 208 -width 308
message .frame07.box07message -aspect 150 -bg ivory -text "You can add more explanatory text here if desired"
place .frame07.box07message -x 4 -y 4 -height 200 -width 300 -anchor nw -bordermode ignore
bind .frame07.box07message <Button-1> {destroy .frame07}}

#######################################################################################################################
set u [Notebook:frame .top.n Classification]
canvas $u.1 -relief groove -bg black -yscrollcommand "$u.sb1 set" -xscrollcommand "$u.sb2 set" -scrollregion {0 0 1200 1200}
scrollbar $u.sb2 -orient horizontal -command "$u.1 xview"
pack $u.sb2 -side bottom -fill x
scrollbar $u.sb1 -orient vertical -command "$u.1 yview"
pack $u.sb1 -side right -fill y
pack $u.1 -side left  -fill both -expand 1



set v [Notebook:frame .top.n Staging]
canvas $v.1 -relief groove -bg black -yscrollcommand "$v.sb1 set" -xscrollcommand "$v.sb2 set" -scrollregion {0 0 1200 1200}
scrollbar $v.sb2 -orient horizontal -command "$v.1 xview"
pack $v.sb2 -side bottom -fill x
scrollbar $v.sb1 -orient vertical -command "$v.1 yview"
pack $v.sb1 -side right -fill y
pack $v.1 -side left  -fill both -expand 1




set x [Notebook:frame .top.n Treatment]
canvas $x.1 -relief groove -bg black -yscrollcommand "$x.sb1 set" -xscrollcommand "$x.sb2 set" -scrollregion {0 0 1200 1200}
scrollbar $x.sb2 -orient horizontal -command "$x.1 xview"
pack $x.sb2 -side bottom -fill x
scrollbar $x.sb1 -orient vertical -command "$x.1 yview"
pack $x.sb1 -side right -fill y
pack $x.1 -side left  -fill both -expand 1


set y [Notebook:frame .top.n Education]
canvas $y.1 -relief groove -bg black -yscrollcommand "$y.sb1 set" -xscrollcommand "$y.sb2 set" -scrollregion {0 0 1200 1200}
scrollbar $y.sb2 -orient horizontal -command "$y.1 xview"
pack $y.sb2 -side bottom -fill x
scrollbar $y.sb1 -orient vertical -command "$y.1 yview"
pack $y.sb1 -side right -fill y
pack $y.1 -side left  -fill both -expand 1



set z [Notebook:frame .top.n Prog.Note]
canvas $z.1 -relief groove -bg peachpuff -yscrollcommand "$z.sb1 set" -xscrollcommand "$z.sb2 set" -scrollregion {0 0 1200 1200}
scrollbar $z.sb2 -orient horizontal -command "$z.1 xview"
;#pack $z.sb2 -side bottom -fill x
scrollbar $z.sb1 -orient vertical -command "$z.1 yview"
;#pack $z.sb1 -side right -fill y
pack $z.1 -side left  -fill both -expand 1
frame $z.1.frame -height 300
pack $z.1.frame -side left -fill both
text $z.1.frame.text  \
    -background ivory \
    -font -Adobe-Helvetica-Medium-R-Normal-*-*-120-*-*-*-*-*-* \
    -wrap word \
    -xscrollcommand "$z.1.frame.sb1 set" \
    -yscrollcommand "$z.1.frame.sb2 set"
scrollbar $z.1.frame.sb1 -orient horizontal -command "$z.1.frame.text xview"  
scrollbar $z.1.frame.sb2 -orient vertical -command "$z.1.frame.text yview"
pack $z.1.frame.sb1 -side bottom -fill x
pack $z.1.frame.sb2 -side right -fill y
pack $z.1.frame.text -side left -fill both -expand 1
message $z.1.mes1 -text "Progress Note - Generated by Your Responses to the Algorithm" -aspect 250
pack $z.1.mes1 -side top




