#
# Sensus Consulting Ltd (C) 1997
#
# Matt Newman - matt@sensus.org
#
# Implements Win95-style ListView (e.g. Explorer right-hand panel)
#
# Originally derived from tkFDialog (tk8.0)
#
#INDEX\
proc tk++::ListView {} {}

option add *ListView.background white widgetDefault

proc listview {w args} {
	return [uplevel 1 tk++::ListView $w $args]
}
class tk++::ListView {
	inherit itk::Widget

	constructor {args} {}
	destructor {}

	public {
		method clear {}
		method delete {first {last ""}}
		method get {}
		method index {index}
		method insert {index label image tag}
		method invoke {}
		method see {rTag}
		method select {rTag {callbrowse 1}}
	}

	itk_option define -command command Command ""
	itk_option define -browsecmd browseCmd BrowseCmd ""
	itk_option define -font	font Font {{MS Sans Serif} 8}
	itk_option define -mode	mode mode list {_refresh}
	itk_option define -padx	padX PadX 2
	itk_option define -pady	padY PadY 1

	protected {
		method _max {id w h}
		method _refresh {{when later}}
		method _refresh_list {W H}
		method _AutoScan {}
		method _Btn1 {x y}
		method _Motion1 {x y}
		method _Double1 {x y}
		method _ReturnKey {}
		method _Leave1 {x y}
		method _FocusIn {}
		method _UpDown {amount}
		method _LeftRight {amount}
		method _KeyPress {key}
		method _Reset {}
		method _move {id x y}
		method _see {view size t0 t1 c0 off}
		method _SelectAtXY {x y}

		variable curItem	""
		variable ids		""
		variable items
		variable maxIW	16
		variable maxIH	16
		variable maxTW	1
		variable maxTH	1
		variable rebuild	""
		variable selected	""
		variable n_col	""
		variable n_row	""
	}
}
body tk++::ListView::constructor {args} {
	itk_component add scroll {
		scroll $itk_interior.s canvas -width 1 -height 1 \
				-highlightthickness 0 \
				-bd 0 -relief flat -background white
	} {
		keep -relief -borderwidth
	}	
	itk_component add canvas {
		$itk_component(scroll) child
	} {
		keep -background -selectbackground
		keep -selectborderwidth -selectforeground
		keep -width -height
		keep -highlightthickness
	}
	pack $itk_component(scroll) -fill both -expand yes

	# Creates the event bindings.
	#
	bind $itk_component(canvas) <Configure>		[code $this _refresh now]

	bind $itk_component(canvas) <1>         		[code $this _Btn1 %x %y]
	bind $itk_component(canvas) <B1-Motion>		[code $this _Motion1 %x %y]
	bind $itk_component(canvas) <Double-1>		[code $this _Double1 %x %y]
	bind $itk_component(canvas) <ButtonRelease-1>	"tkCancelRepeat"
	bind $itk_component(canvas) <B1-Leave>		[code $this _Leave1 %x %y]
	bind $itk_component(canvas) <B1-Enter>		"tkCancelRepeat"

	bind $itk_component(canvas) <Up>			[code $this _UpDown -1]
	bind $itk_component(canvas) <Down>			[code $this _UpDown 1]
	bind $itk_component(canvas) <Left>			[code $this _LeftRight -1]
	bind $itk_component(canvas) <Right>			[code $this _LeftRight 1]
	bind $itk_component(canvas) <Return>		[code $this _ReturnKey ]
	bind $itk_component(canvas) <KeyPress>		[code $this _KeyPress %A]
	bind $itk_component(canvas) <Control-KeyPress>	";"
	bind $itk_component(canvas) <Alt-KeyPress>	";"

	bind $itk_component(canvas) <FocusIn>		[code $this _FocusIn ]

	eval itk_initialize $args
}
body tk++::ListView::destructor {} {
	after cancel $rebuild
}
# Deletes all the items inside the canvas subwidget and reset the IconList's
# state.
#
body tk++::ListView::clear {} {

	$itk_component(canvas) delete all
	catch {unset items}
	set maxIW 16
	set maxIH 16
	set maxTW 1
	set maxTH 1
	set curItem  {}
	set ids  {}
}
body tk++::ListView::delete {first {last ""}} {

	if {$last == ""} {set last $first}
	set dust	[lrange $ids $first $last]
	foreach id $dust {
		unset items($id)
		$itk_component(canvas) delete $id
	}
	set ids	[lreplace $ids $first $last]

	_refresh 
}
# Returns the selected item
#
body tk++::ListView::get {} {
	if [info exists selected] {
		return $selected
	} else {
		return ""
	}
}

# Adds an icon into the IconList with the designated image and text
#
body tk++::ListView::insert {idx text image data} {
	set id	[uid $this]

	$itk_component(canvas) create image -1000 -1000 -image $image -anchor w \
						-tags [list $id $id.image]
	$itk_component(canvas) create text  -1000 -1000 -text  $text  -anchor w \
						-font $itk_option(-font) \
						-tags [list $id $id.text]
    
	lassign [_max $id.image $maxIW $maxIH] maxIW maxIH
	lassign [_max $id.text $maxTW $maxTH] maxTW maxTH

	set ids	[linsert $ids $idx $id]
	set items($id)	[list $id $text $image $data]

	_refresh 
}
# Gets called when the user invokes the IconList (usually by double-clicking
# or pressing the Return key).
#
body tk++::ListView::invoke {} {
	if {[string compare $itk_option(-command) ""] && \
		[info exists selected]} {
		lassign $items($curItem) xid text image data
		eval $itk_option(-command) [list $data]
	}
}

body tk++::ListView::see {o} {
	lassign [$itk_component(canvas) bbox all] x0 y0 x1 y1
	lassign [$itk_component(canvas) bbox $o] cx0 cy0 cx1 cy1
	set rw [winfo width $itk_component(canvas)]
	set rh [winfo height $itk_component(canvas)]

	_see yview $rh $y0 $y1 $cy0 [expr $maxIH+$maxTH]
	_see xview $rw $x0 $x1 $cx0 [expr $maxIW+$maxTW]
}

body tk++::ListView::select {id {callBrowse 1}} {
	if ![info exists items($id)] {
		return
	}
	lassign $items($id) xid text image data

	$itk_component(canvas) select clear
	$itk_component(canvas) select from $id.text 0
	$itk_component(canvas) select to $id.text end

	set curItem $id
	if {[info exists selected] && \
		[string compare $selected $text]==0} {
		set callBrowse 0
	}
	set selected $text

	see $id

	if {$callBrowse} {
		if [string compare $itk_option(-browsecmd) ""] {
			eval $itk_option(-browsecmd) [list $tag]
		}
	}
}


body tk++::ListView::_max {id w h} {
	set b [$itk_component(canvas) bbox $id]
	set iW [expr [lindex $b 2]-[lindex $b 0]]
	set iH [expr [lindex $b 3]-[lindex $b 1]]
	if {$w < $iW} {
		set w $iW
	}
	if {$h < $iH} {
		set h $iH
	}
	return [list $w $h]
}
# Places the icons in a column-major arrangement.
#
# mode=list arrange downwards, within current height,
#	accumulating cols, which may force x scrolling
#
# mode=small arrange horizontally, within available width,
#	accumulating rows, which may force y scrolling
#
# mode=large (as small) but labels centred below images, and
#	images at 32x32, instead of usual 16x16
#
body tk++::ListView::_refresh {{when later}} {
	if {$when == "later"} {
		if {$rebuild == ""} {
			set rebuild [after idle [code $this _refresh now]]
		}
		return ""
	} elseif {$when != "now"} {
		error "bad option \"$when\": should be now or later"
	}
	after cancel $rebuild
	set rebuild ""

	switch -glob -- $itk_option(-mode) {
	li*	{set cmd _refresh_list}
	sm*	{set cmd _refresh_small}
	la*	{set cmd _refresh_large}
	}
	set W [winfo width  $itk_component(canvas)]
	set H [winfo height $itk_component(canvas)]
	set pad [expr [$itk_component(canvas) cget -highlightthickness] + \
				[$itk_component(canvas) cget -bd]]
	incr W -[expr $pad*2]
	incr H -[expr $pad*2]

	lassign [$cmd $W $H] dx dy

	set n_col [expr $H/$dy]
	if {$n_col < 1} {set n_col 1}

	set n_row [expr $W/$dx]
	if {$n_row < 1} {set n_row 1}

	if {$curItem != {}} {
		select $curItem 0
	}
}
body tk++::ListView::_refresh_list {W H} {
	set dx [expr $maxIW + $maxTW + $itk_option(-padx)]
	set tx [expr $maxIW + $itk_option(-padx)]
	set dy [expr $maxIH + $itk_option(-pady)]

	set x 0
	set y [expr $maxIH/2]
	foreach id $ids {
		# reposition
		_move $id.image $x $y
		_move $id.text [expr $x + $tx] $y

		incr y $dy
		if {($y + $dy) > $H} {
			set y [expr $maxIH/2]
			incr x $dx
		}
	}
	$itk_component(canvas) config -scrollregion "0 0 $x $H"

	return [list $dx $dy]
}
#
# This procedure is invoked when the mouse leaves an entry window
# with button 1 down.  It scrolls the window up, down, left, or
# right, depending on where the mouse left the window, and reschedules
# itself as an "after" command so that the window continues to scroll until
# the mouse moves back into the window or the mouse button is released.
#
# Arguments:
# w -		The IconList window.
#
body tk++::ListView::_AutoScan {} {
	global tkPriv

	if {![winfo exists $itk_path]} return
	set x $tkPriv(x)
	set y $tkPriv(y)

	if {$x >= [winfo width $itk_component(canvas)]} {
		$itk_component(canvas) xview scroll 1 units
	} elseif {$x < 0} {
		$itk_component(canvas) xview scroll -1 units
	} elseif {$y >= [winfo height $itk_component(canvas)]} {
		# do nothing
	} elseif {$y < 0} {
		# do nothing
	} else {
		return
	}
	_Motion1 $x $y
	set tkPriv(afterId) [after 50 [code $this _AutoScan]]
}

body tk++::ListView::_Btn1 {x y} {
	focus $itk_component(canvas)
	_SelectAtXY $x $y
}

# Gets called on button-1 motions
#
body tk++::ListView::_Motion1 {x y} {
	global tkPriv
	set tkPriv(x) $x
	set tkPriv(y) $y

	_SelectAtXY $x $y
}

body tk++::ListView::_Double1 {x y} {
	if {$curItem != {}} {
		invoke 
	}
}

body tk++::ListView::_ReturnKey {} {
	invoke 
}

body tk++::ListView::_Leave1 {x y} {
	global tkPriv

	set tkPriv(x) $x
	set tkPriv(y) $y
	_AutoScan 
}

body tk++::ListView::_FocusIn {} {
	if [llength $ids]==0 return

	if {$curItem == {}} {
		select [lindex $ids 0]
	}
}

# _UpDown --
#
# Moves the active element up or down by one element
#
# Arguments:
# w -		The IconList widget.
# amount -	+1 to move down one item, -1 to move back one item.
#
body tk++::ListView::_UpDown {amount} {
	if [llength $ids]==0 return

	set old	$curItem
	if {$old == ""} {
		set id [lindex $ids 0]
	} else {
		set off	[lsearch $ids $old]
		set id [lindex $ids [expr $off + $amount]]
		if [string compare $id ""]==0 {
			set id $old
		}
	}
	select $id
}

# _LeftRight --
#
# Moves the active element left or right by one column
#
# Arguments:
# w -		The IconList widget.
# amount -	+1 to move right one column, -1 to move left one column.
#
body tk++::ListView::_LeftRight {amount} {
	if [llength $ids]==0 return

	set old	$curItem
	if {$old == ""} {
		set id [lindex $ids 0]
	} else {
		set off	[lsearch $ids $old]
		set id [lindex $ids [expr $off + ($amount * $n_col)]]
		if [string compare $id ""]==0 {
			set id $old
		}
	}
	select $id
}

#----------------------------------------------------------------------
#		Accelerator key bindings
#----------------------------------------------------------------------

# _KeyPress --
#
#	Gets called when user enters an arbitrary key in the listbox.
#
body tk++::ListView::_KeyPress {key} {
	global tkPriv

	append tkPriv(ILAccel,$itk_path) $key
	goto $tkPriv(ILAccel,$itk_path)
	catch {
		after cancel $tkPriv(ILAccel,$itk_path,afterId)
	}
	set tkPriv(ILAccel,$itk_path,afterId) [after 500 [code $this _Reset]]
}


body tk++::ListView::_Reset {} {
	global tkPriv

	catch {unset tkPriv(ILAccel,$itk_path)}
}
# abs move
body tk++::ListView::_move {id x y} {
	set xy	[$itk_component(canvas) coords $id]
	set cx	[lindex $xy 0]
	set cy	[lindex $xy 1]

	# do a delta-move to correct location
	$itk_component(canvas) move $id [expr $x - $cx] [expr $y - $cy]
}
body tk++::ListView::_see {view size t0 t1 c0 off} {
	lassign [$itk_component(canvas) $view] pv0 pv1
	set dt	[expr double($t1 - $t0)]
	set pc0	[expr ($c0 - $t0)/$dt]
	set pc1	[expr (($c0+$off) - $t0)/$dt]

	if {$dt < $size} {
		# Display area is smaller than window
#echo _see $view - moveto 0.0
		$itk_component(canvas) $view moveto 0.0
	} elseif {$pc0 > $pv0 && $pc1 < $pv1} {
		# donothing - fits w/o scrolling
#echo _see $view - donothing
	} elseif {($pc1 - $pc0) > ($pv1 - $pv0)} {
		# Larger than window
#echo _see $view - moveto $pc0
		$itk_component(canvas) $view moveto $pc0
	} else {
#echo _see $view - moveto $pv0 + ($pc1 - $pv1)
		$itk_component(canvas) $view moveto [expr $pv0 + ($pc1 - $pv1)] 
	}
}

body tk++::ListView::_SelectAtXY {x y} {
	set tag [$itk_component(canvas) find closest [$itk_component(canvas) canvasx $x] \
					[$itk_component(canvas) canvasy $y]]
	if {$tag == ""} return

	# 1st tag is always object
	set o [lindex [$itk_component(canvas) itemcget $tag -tags] 0]
	select $o
}
