#
# Sensus Consulting Ltd (C) 1998
#
# Matt Newman - matt@sensus.org
#
# Emulation of "real" [incr Tk].
#
# This is not 100% compatible, due to the underlying class structure
# being different, but for people familier with [incr Tk] it should be
# very easy to use, and also to convert code from.
#
# Credit for [incr Tk] goes to:
#	Michael J. McLennan
#	Bell Labs Innovations for Lucent Technologies
#
# COMPATIBILITY:
#
# change %q back to %W in bindings
# change "uplevel [info context]::$itk_component(...) ..."
#		to the more simple: $itk_component(...)
#
#INDEX\
proc usual {} {}

package require tcl++
package provide tk++ 2.0.2

namespace eval tk++ {
	variable usual

	namespace export usual focus

	namespace eval parser {
		#
		# Parse component body
		#
		proc parse {class body} {
			::variable __

			if {[info exists __]} {unset __}
			set __(class)	$class
			eval $body
		}
		proc keep {args} {
			::variable __
			foreach opt $args {
				set __($opt) $opt
			}
		}
		proc ignore {args} {
			::variable __
			foreach opt $args {
				if {[_info exists __($opt)]} {
					unset __($opt)
				}
			}
		}
		proc rename {option switchName resourceName resourceClass} {
			::variable __
			set __($option) [list $switchName $resourceName $resourceClass]
		}
		proc usual {{class ""}} {
			::variable __
			if {$class == ""} {
				set class $__(class)
			}
			eval [tk++::usual $class]
		}
	}
}
namespace eval tcl++::parser {
	namespace export itk_option

	::proc itk_option {option args} {
		upvar 1 _info _info
		if {$option != "define"} {
			error "bad option \"$option\": must be define"
		}
		set argc [llength $args]
		if {$argc != 4 && $argc != 5} {
			error "wrong # of args: option define switchName resourceName resourceClass init ?config?"
		}
		set opt [string range [lindex $args 0] 1 end]
		set resN [lindex $args 1]
		set resC [lindex $args 2]
		set init [lindex $args 3]
		set config [lindex $args 4]

		set _info(option,$opt) [list public $_info(class) -$opt $resN $resC $init]
		set _info(config,$opt) $config
	}
}
proc tk++::usual {tag {body "_NONE_"}} {
	variable usual
	if {![string match ::* $tag]} {set tag ::$tag}
	if {$body == "_NONE_"} {
		if {[_info exists usual($tag)]} {
			return $usual($tag)
		} else {
			return ""
		}
	} else {
		set usual($tag) $body
		return ""
	}
}
proc tk++::focus args {
	if {[llength $args]==1} {
		set w [lindex $args 0]
		if [winfo exists $w._] {
			set args [list $w._]
		}
	} elseif {$args == ""} {
		set w [_focus]
		if [string match *._ $w] {
			regsub {\._$} $w {} w
		}
		return $w
	}
	eval _focus $args
}
rename ::focus ::_focus

namespace import -force tk++::usual tk++::focus
